An S4 class used to create a job specification.
memoryThe amount of memory used by the job
cpusThe number of cpus used by the job
walltimeThe maximum amount of time the job should run
qosName of the "quality of service" (qos) that the job should be submitted as
output.fileThe path to the Slurm output file
email.completeIf used, Slurm will email the given email address when the job is finished.
other.argsA string containing additional flags and values to pass to Slurm. These will overwrite previously given parameters when submitted.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.