An S4 class used to create a job submission.
script.fileRelative path to the script
clusterAddress of cluster you want to submit to.
profileA JobProfile type object.
script.argsString containing all arguments to the submitted Rscript to be executed remotely on the cluster.
condaString containing the name of a valid conda environment on the cluster to be used to execute R.
singularityString path or URI of a Singularity container to execute Rscript inside of.
r.bin.argsString containing all arguments to pass to the Rscript binary.
r.dataString containing the name of an R data object in the search path.
local.dataString containing a list of paths to one or more local file(s). WARNING: Large files may take a long time to sync.
target.dirPath to directory to create .slurmsubmit/ directory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.